Profile Hidden Markov Models
============================

.. autoclass:: pyhmmer.plan7.HMM
   :special-members: __init__
   :members:
   :exclude-members: sample

   .. automethod:: pyhmmer.plan7.HMM.sample


.. autoclass:: pyhmmer.plan7.Profile
   :special-members: __init__
   :members:

.. autoclass:: pyhmmer.plan7.OptimizedProfile
   :special-members: __init__
   :members:

.. autoclass:: pyhmmer.plan7.OptimizedProfileBlock
   :special-members: __init__
   :members: